@@ -8,13 +8,14 @@
 #ifndef OWNCLOUD_H
 #define OWNCLOUD_H
 
-#include <QUrl>
 #include <QHash>
+#include <QUrl>
 
 #include <kaccountsuiplugin.h>
 
-namespace KDeclarative {
-    class QmlObject;
+namespace KDeclarative
+{
+class QmlObject;
 }
 
 class OwnCloudWizard : public KAccountsUiPlugin
@@ -24,18 +25,18 @@ class OwnCloudWizard : public KAccountsUiPlugin
     Q_INTERFACES(KAccountsUiPlugin)
 
 public:
-    explicit OwnCloudWizard(QObject *parent = 0);
+    explicit OwnCloudWizard(QObject *parent = nullptr);
     virtual ~OwnCloudWizard();
 
-    virtual void init(KAccountsUiPlugin::UiType type) Q_DECL_OVERRIDE;
-    virtual void setProviderName(const QString &providerName) Q_DECL_OVERRIDE;
-    virtual void showNewAccountDialog() Q_DECL_OVERRIDE;
-    virtual void showConfigureAccountDialog(const quint32 accountId) Q_DECL_OVERRIDE;
-    virtual QStringList supportedServicesForConfig() const Q_DECL_OVERRIDE;
+    virtual void init(KAccountsUiPlugin::UiType type) override;
+    virtual void setProviderName(const QString &providerName) override;
+    virtual void showNewAccountDialog() override;
+    virtual void showConfigureAccountDialog(const quint32 accountId) override;
+    virtual QStringList supportedServicesForConfig() const override;
 
 private:
     QHash<QString, int> m_services;
     KDeclarative::QmlObject *m_object;
 };
 
-#endif //OWNCLOUD_H
+#endif // OWNCLOUD_H
